/* $Id$

   Copyright (C) 2020-2021 Aamot Software
   Author(s): Ole Aamot <ole@gnome.org>
   License: GNU GPL version 3
   Version: 1.1.0 (2021-07-27)
   Website: http://www.gingerblue.org/

 */

#include <glib/gi18n.h>
#include <gtk/gtk.h>
#include <gst/gst.h>
#include "gingerblue.h"
#include "gingerblue-main-loop.h"

int main_app (gint argc, gchar *argv[]) {
	GingerblueData *gingerblue_config;
        GtkWindow *gingerblue_window;
	gtk_init (&argc, &argv);
        gingerblue_config = main_config ("studios.gingerblue.org");
	gingerblue_window = gingerblue_main_loop (gingerblue_config);
	gtk_widget_show_all (gingerblue_window);
	gst_init(&argc, &argc);
	gtk_main();	
	return (0);
}
