/* $Id$
   
   Copyright (C) 2018-2021 Aamot Software
   Author(s): Ole Aamot <ole@gnome.org>
   License: GNU GPL version 3
   Version: 1.1.0 (2021-07-27)
   Website: http://www.gingerblue.org/
   
*/

#include <libxml/xmlmemory.h>
#include <libxml/parser.h>

GtkWidget *gb_song_new (gchar *title);
GtkWidget *gb_song_quit (gchar *title);
