/* $Id$

   Copyright (C) 2018-2021 Aamot Software
   Author(s): Ole Aamot <ole@gnome.org>
   License: GNU GPL version 3
   Version: 1.1.0 (2021-07-27)
   Website: http://www.gingerblue.org/
 
 */

#include <glib/gstdio.h>
#include <glib/gi18n.h>
#include <gst/gst.h>
#include <gtk/gtk.h>
#include "gingerblue.h"

GtkWidget *knob (GingerblueData *data, GtkWidget *line, gint jack, gchar *label, gboolean lpf, gboolean hpf) {
	GtkWidget *knob;
	knob = gtk_volume_button_new ();
	return (knob);
}
